@@ -1,24 +1,29 @@
 #' Get links to datasets related to a unique ID from an NCBI database
 #'
-#' Contstructs a query with the given arguments and downloands the XML
-#' document created by that query. Unique IDs from linked-databases
+#' Constructs a query with the given arguments and downlands the XML
+#' document created by that query. 
 #'
 #'@import XML
 #'@export
-#'@param db character Name of the database to search for links (or use "all" to earch all NCBI databases
-#'@param dbfrom character Name of database from which the Id(s) orginate
+#'@param db character Name of the database to search for links (or use "all" to 
+#' search all databases available for \code{db}. \code{entrez_db_links} allows you
+#' to discover databases that might have linked information (see examples).
+#'@param dbfrom character Name of database from which the Id(s) originate
 #'@param \dots character Additional terms to add to the request
 #'@param config vector configuration options passed to httr::GET  
-#'@seealso \code{\link[httr]{config}} for avaliable configs 
+#'@seealso \code{\link[httr]{config}} for available configs 
 #'@return An elink object containing vectors of unique IDs
 #' the vectors names take the form [db_from]_[db_to]
 #'@return file XMLInternalDocument xml file resulting from search, parsed with
 #'\code{\link{xmlTreeParse}}
 #' @examples
-#'
-#'  pubmed_search <- entrez_search(db = "pubmed", term = "10.1016/j.ympev.2010.07.013[doi]")
-#'  linked_data <- entrez_link(dbfrom = "pubmed", id = pubmed_search$ids, db = "all")
-#' nucleotide_IDs <- linked_data$pubmed_nuccore
+#' \donttest{
+#'  (pubmed_search <- entrez_search(db = "pubmed", term ="10.1016/j.ympev.2010.07.013[doi]"))
+#'  (linked_dbs <- entrez_db_links("pubmed"))
+#'  nucleotide_data <- entrez_link(dbfrom = "pubmed", id = pubmed_search$ids, db ="nuccore")
+#'  #All the links
+#'  entrez_link(dbfrom="pubmed", db="all", id=pubmed_search$ids)
+#'}
 #'
 
 entrez_link <- function(db, dbfrom, config=NULL, ...){
@@ -46,5 +51,5 @@ entrez_link <- function(db, dbfrom, config=NULL, ...){
 print.elink <- function(x, ...){
    len <- length(x)
    cat(paste("elink result with ids from", len - 1, "databases:\n"))
-   print (names(x)[-len])
+   print (names(x)[-len], quote=FALSE)
 }
